Jenny Tc has uploaded this change for review.

View Change

intel/skylake: nhlt: Add 24 bit blobs for Max98373

Enable 24 bit nhlt blobs and remove 16 bit blobs. 16 bit and 24 bit
blobs cannot be supported together since the OS NHLT parsing relies
on container bit format. The container bit format for 16 and 24 bit
capture are same (32) and putting both blobs in configs results in
selecting the first blob. To enable 24 and 16 bit blobs together, the
core nhlt parsing logic has to be changed which would impact SKL and
KBL platforms. In order to minimize the impact, the 16 bit blob is
removed considering that the machine driver for max98373 is expected to
support only format due to topology configuration for 16 and 24 bit.

BUG=b:110795132
BRANCH=none
TEST=Verify playback after flashing
CQ-DEPEND=*806750

Change-Id: I62cc109fb0aca9269736779a6ce80980b0571b78
Signed-off-by: Jenny TC <jenny.tc@intel.com>
---
M src/soc/intel/skylake/nhlt/Makefile.inc
M src/soc/intel/skylake/nhlt/max98373.c
2 files changed, 6 insertions(+), 16 deletions(-)

git pull ssh://review.coreboot.org:29418/coreboot refs/changes/35/31635/1
diff --git a/src/soc/intel/skylake/nhlt/Makefile.inc b/src/soc/intel/skylake/nhlt/Makefile.inc
index 5c8bd80..548747a 100644
--- a/src/soc/intel/skylake/nhlt/Makefile.inc
+++ b/src/soc/intel/skylake/nhlt/Makefile.inc
@@ -21,7 +21,6 @@
DMIC_4CH_48KHZ_32B = dmic-4ch-48khz-32b.bin
NAU88L25 = nau88l25-2ch-48khz-24b.bin
MAX98357_RENDER = max98357-render-2ch-48khz-24b.bin
-MAX98373_RENDER_16B = max98373-render-2ch-48khz-16b.bin
MAX98373_RENDER_24B = max98373-render-2ch-48khz-24b.bin
MAX98927_RENDER_24B = max98927-render-2ch-48khz-24b.bin
MAX98927_RENDER_16B = max98927-render-2ch-48khz-16b.bin
diff --git a/src/soc/intel/skylake/nhlt/max98373.c b/src/soc/intel/skylake/nhlt/max98373.c
index 0e3a413..a781943 100644
--- a/src/soc/intel/skylake/nhlt/max98373.c
+++ b/src/soc/intel/skylake/nhlt/max98373.c
@@ -25,35 +25,26 @@
.speaker_mask = SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT,
.settings_file = "max98373-render-2ch-48khz-24b.bin",
},
- /* 48 KHz 16-bits per sample. */
- {
- .num_channels = 2,
- .sample_freq_khz = 48,
- .container_bits_per_sample = 16,
- .valid_bits_per_sample = 16,
- .speaker_mask = SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT,
- .settings_file = "max98373-render-2ch-48khz-16b.bin",
- }
};

static const struct nhlt_format_config max98373_capture_formats[] = {
/* 48 KHz 16-bits per sample - Quad Channel. */
{
.num_channels = 4,
.sample_freq_khz = 48,
.container_bits_per_sample = 32,
- .valid_bits_per_sample = 16,
+ .valid_bits_per_sample = 24,
.speaker_mask = SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT,
- .settings_file = "max98373-render-2ch-48khz-16b.bin",
+ .settings_file = "max98373-render-2ch-48khz-24b.bin",
},
/* 48 KHz 16-bits per sample - Stereo Channel */
{
.num_channels = 2,
.sample_freq_khz = 48,
.container_bits_per_sample = 32,
- .valid_bits_per_sample = 16,
+ .valid_bits_per_sample = 24,
.speaker_mask = SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT,
- .settings_file = "max98373-render-2ch-48khz-16b.bin",
+ .settings_file = "max98373-render-2ch-48khz-24b.bin",
},
};
@@ -25,35 +25,26 @@

static const struct nhlt_format_config max98373_capture_formats[] = {
- /* 48 KHz 16-bits per sample - Quad Channel. */
+ /* 48 KHz 24-bits per sample - Quad Channel. */
{
.num_channels = 4,
@@ -25,35 +25,26 @@
},
- /* 48 KHz 16-bits per sample - Stereo Channel */
+ /* 48 KHz 24-bits per sample - Stereo Channel */
{
.num_channels = 2,


To view, visit change 31635. To unsubscribe, or for help writing mail filters, visit settings.

Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I62cc109fb0aca9269736779a6ce80980b0571b78
Gerrit-Change-Number: 31635
Gerrit-PatchSet: 1
Gerrit-Owner: Jenny Tc <jenny.tc@intel.com>
Gerrit-MessageType: newchange